# Changelog

<!--
   You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst
-->

<!-- towncrier release notes start -->

## 1.3.1 (2026-03-30)


### Bug fixes:

- Flicrk Api key is not required in behavior field @erral 

## 1.3 (2026-03-30)


### New features:

- Allow configuring local Flickr API settings to override site-wide settings @erral 


### Bug fixes:

- Allow entering usernames and delegate converting it user-id @erral 


### Internal:

- Refactor Flickr connection to be reusable @erral 

## 1.2 (2025-12-07)


### New features:

- Add restapi support through @inherit endpoint @erral 

## 1.1.0 (2025-10-02)


### New features:

- Make it work without requiring plone.app.multilingual @erral [#1](https://github.com/codesyntax/cs_flickrgallery/issues/1)

## 1.0.0 (2025-10-02)


### New features:

- Initial release @erral
